@@ -8,3 +8,7 @@ from .SwitchCase import *
 from .test_tk import *
 from .tests import *
 
+
+def Run():
+    import unittest
+    unittest.main()
